@@ -1,8 +1,7 @@
-
 #include "catch.hpp"
 
-#include "variant.hpp"
-#include "variant_io.hpp"
+#include <mapbox/variant.hpp>
+#include <mapbox/variant_io.hpp>
 
 // https://github.com/mapbox/variant/issues/21
 
@@ -11,6 +10,12 @@ static int count;
 struct t1
 {
     int value;
+
+    t1(t1 const& rhs)
+        : value(rhs.value)
+    {
+        ++count;
+    }
     t1(int v) : value(v)
     {
         ++count;
@@ -37,7 +42,8 @@ TEST_CASE("set() works cleanly even if the constructor throws ", "[variant]")
 
     count = 0;
     {
-        variant_type v{42};
+        t1 obj{42};
+        variant_type v = obj;
         REQUIRE(v.is<t1>());
         REQUIRE(v.get<t1>().value == 42);
         REQUIRE_THROWS({
